@@ -1,12 +1,20 @@
 import hashlib
 from typing import Optional
 
-from arcsecond import ArcsecondAPI
-
 from oort.shared.config import write_config_section_values
 
 
 class Identity(object):
+    @classmethod
+    def from_folder_section(cls, folder_section, debug=False):
+        return cls(folder_section.get('username'),
+                   folder_section.get('api_key'),
+                   folder_section.get('subdomain', ''),
+                   folder_section.get('role', ''),
+                   folder_section.get('telescope', ''),
+                   folder_section.get('longitude', ''),
+                   debug)
+
     def __init__(self,
                  username: str,
                  api_key: str,
@@ -54,14 +62,14 @@ class Identity(object):
     def get_args_string(self):
         return f"{self.username},{self.api_key},{self.subdomain},{self.role},{self.telescope},{self.longitude},{str(self.debug)}"
 
-    def save_with_folder(self, upload_folder):
-        folder_hash = hashlib.shake_128(upload_folder.encode('utf8')).hexdigest(3)
+    def save_with_folder(self, upload_folder_path: str):
+        folder_hash = hashlib.shake_128(upload_folder_path.encode('utf8')).hexdigest(3)
         write_config_section_values(f'watch-folder-{folder_hash}',
-                                    username=ArcsecondAPI.username(),
-                                    api_key=ArcsecondAPI.api_key(debug=self.debug),
+                                    username=self._username,
+                                    api_key=self._api_key,
                                     subdomain=self.subdomain or '',
                                     role=self.role or '',
-                                    path=upload_folder,
+                                    path=upload_folder_path,
                                     telescope=self.telescope or '',
                                     longitude=str(self._longitude) if self._longitude else '',
                                     debug=str(self.debug))
